@@ -2,8 +2,8 @@
 # -*- mode: perl; coding: utf-8; tab-width: 4; -*-
 
 use strict;
+use warnings;
 use lib qw(blib/lib blib/arch);
-
 use Cv;
 use File::Basename;
 
@@ -13,8 +13,8 @@ my $img = Cv->loadImage($imagename);
 # check if the image has been loaded properly
 die "$0: Can not load image $imagename" unless $img;
 
-my $rng = Cv::RNG->new(-1);
-my $noise = Cv::Image->new($img->sizes, CV_32FC1);
+my $rng = Cv->RNG(-1);
+my $noise = $img->new(CV_32FC1);
 $rng->randArr($noise, CV_RAND_NORMAL, cvScalarAll(0), cvScalarAll(20));
 $noise->smooth($noise, CV_GAUSSIAN, 5, 5, 1, 1);
 
